@@ -22,21 +22,9 @@ def test_set_api_key(capsys):
 
 def test_login(capsys, user_password_key):
     cmd = LogInCommand()
-    with pytest.raises(InvalidInputError):
-        cmd.execute(None, None, None)
-
-    with pytest.raises(InvalidInputError):
-        cmd.execute(None, "me", None)
-
     u, p, k = user_password_key
-
-    assert cmd.execute(u, p, None) is True
+    assert cmd.execute(k) is True
     out, err = capsys.readouterr()
     assert out == "Login successful!\n"
-    assert cmd.execute(None, None, k) is True
-    out, err = capsys.readouterr()
-    assert out == "Login successful!\n"
-
-    assert cmd.execute(u, "whatever", None) is False
-    out, err = capsys.readouterr()
-    assert err == "Request failed: Incorrect username or password\n"
+    with pytest.raises(InvalidInputError):
+        cmd.execute(None)
