@@ -1,7 +1,8 @@
+from typing import Callable, Dict, List
+
 import numpy as np
 import pandas as pd
 import pytest
-from typing import List, Dict, Callable
 
 from tktl import Tktl
 from tktl.core.exceptions.exceptions import ValidationException
