@@ -6,12 +6,15 @@ TEMPLATE_PROJECT_DIRS = [
 
 TEMPLATE_PROJECT_FILES = [
     "template/src/endpoints.py",
-    "template/assets/model.pkl",
-    "template/assets/test.pqt",
+    "template/assets/model.joblib",
+    "template/assets/loans_test.pqt",
     "template/tests/test_accuracy.py",
+    "template/tests/test_plausibility.py",
+    "template/tests/test_schema.py",
     "template/.gitignore",
     "template/.gitattributes",
     "template/Dockerfile",
+    "template/.dockerignore",
     "template/README.md",
     "template/requirements.txt",
 ]
@@ -28,13 +31,14 @@ service:
   # Replicas are exact copies of your service, each request will be randomly directed to each of them
   replicas: 2
 
-  # Can be gpu or cpu
-  compute_type: cpu
+  # Format: <instance_kind>.<instance_size>
+  # Only 'gp' (general purpose) instance_kind is supported for now
+  # instance_size can be: small, medium, large
+  instance_type: gp.small
 
   # Can be rest or grpc
   service_type: rest
 
-
 # Assets: model and data
 # Assets are the artifacts that comprise model and data.  These will be loaded inside the container
 # when it gets built. Tktl will automatically package them for you, so all you need to do
@@ -64,4 +68,6 @@ model:
 data:
   path: assets/data.pkl
   version: 1
+
+version: {version}
 """
