@@ -1,7 +1,8 @@
-from typing import Union, List
+from typing import List, Union
 
 from pydantic import BaseModel
-from tktl.core.t import ProjectAssetT, ProjectAssetSourceT, ServiceComputeT, ServiceT
+
+from tktl.core.t import InstanceTypeT, ProjectAssetSourceT, ProjectAssetT, ServiceT
 
 
 class ProjectContentsBase(BaseModel):
@@ -32,7 +33,7 @@ class ProjectAsset(ProjectContentsBase):
 
 class TktlServiceConfigSchema(BaseModel):
     replicas: int
-    compute_type: ServiceComputeT
+    instance_type: InstanceTypeT
     service_type: ServiceT
 
 
@@ -48,7 +49,7 @@ class TktlYamlConfigSchema(BaseModel):
     service:
 
       replicas: 2
-      compute_type: cpu
+      instance_type: gp.small
       service_type: rest
 
     model:
