@@ -3,13 +3,13 @@ import click_completion
 import requests
 
 from tktl.cli import common
-from tktl.cli.auth import logout, login, save_api_key
+from tktl.cli.auth import login, logout, save_api_key
 from tktl.cli.deployments import deployments
 from tktl.cli.init import init
 from tktl.cli.validate import validate
 from tktl.commands.version import get_version
 from tktl.core.config import settings
-from tktl.core.exceptions import TaktileSdkError, ApplicationError
+from tktl.core.exceptions import ApplicationError, TaktileSdkError
 from tktl.core.loggers import CliLogger
 
 click_completion.init()
